@@ -1,12 +1,10 @@
 using System.Runtime.InteropServices;
 
 namespace FSpot {
-	public class CDExport {
+	public class CDExport : GladeDialog {
 		IPhotoCollection selection;
-		[Glade.Widget] Gtk.Dialog cd_export_dialog;
 
 		[Glade.Widget] Gtk.ScrolledWindow thumb_scrolledwindow;
-		
 		[Glade.Widget] Gtk.CheckButton remove_check;
 		
 
@@ -18,17 +16,10 @@ namespace FSpot {
 		FSpot.ThreadProgressDialog progress_dialog;
 		System.Threading.Thread command_thread;
 
-		[DllImport ("libc")] 
-		extern static int system (string program);
-
-		public CDExport (IPhotoCollection selection)
+		public CDExport (IPhotoCollection selection) : base ("cd_export_dialog")
 		{
 			this.selection = selection;
 			
-			// FIXME this xml file path should be be retrieved from a central location not hard coded there
-			Glade.XML xml = new Glade.XML (null, "f-spot.glade", "cd_export_dialog", null);
-			xml.Autoconnect (this);
-			
 			IconView view = new IconView (selection);
 			view.DisplayDates = false;
 			view.DisplayTags = false;
@@ -44,17 +35,14 @@ namespace FSpot {
 			Dialog.Response += HandleResponse;
 		}
 
-		public Gtk.Dialog Dialog {
-			get {
-				return this.cd_export_dialog;
-			}
-		}
-
 		void HandleBrowseExisting (object sender, System.EventArgs args)
 		{
 			Gnome.Url.Show (dest.ToString ());
 		}
 
+		[DllImport ("libc")] 
+		extern static int system (string program);
+
 		public void Transfer () {
 			try {
 				Dialog.Destroy ();
@@ -108,10 +96,10 @@ namespace FSpot {
 			
 			switch (info.Status) {
 			case Gnome.Vfs.XferProgressStatus.Vfserror:
-				progress_dialog.Message = Mono.Posix.Catalog.GetString ("Error: Error while transfering, Aborting");
+				progress_dialog.Message = Mono.Posix.Catalog.GetString ("Error: Error while transferring; Aborting");
 				return (int)Gnome.Vfs.XferErrorAction.Abort;
 			case Gnome.Vfs.XferProgressStatus.Overwrite:
-				progress_dialog.ProgressText = Mono.Posix.Catalog.GetString ("Error: File Already Exists, Aborting");
+				progress_dialog.ProgressText = Mono.Posix.Catalog.GetString ("Error: File Already Exists; Aborting");
 				return (int)Gnome.Vfs.XferOverwriteAction.Abort;
 			default:
 				return 1;
