@@ -409,7 +409,7 @@ public class PhotoStore : DbStore {
 	static Pixbuf GenerateFromExif (string path, string uri)
 	{
 		try {
-			using (ExifData ed = new ExifData (path)){
+			using (Exif.ExifData ed = new Exif.ExifData (path)){
 				return PixbufUtils.GetThumbnail (ed);
 			}
 		} catch {
@@ -515,12 +515,13 @@ public class PhotoStore : DbStore {
 	{
 		DateTime time;
 		try {
-			using (ExifData ed = new ExifData (path)) {
-				string strtime = ed.LookupString (ExifTag.DateTimeOriginal);
-				time = ExifData.DateTimeFromString (strtime); 
+			using (Exif.ExifData ed = new Exif.ExifData (path)) {
+				Exif.ExifContent content = ed.GetContents (Exif.ExifIfd.Exif);
+				Exif.ExifEntry entry = content.GetEntry (Exif.ExifTag.DateTimeOriginal);
+				time = Exif.ExifUtil.DateTimeFromString (entry.Value); 
 				time = time.ToUniversalTime ();
 			}			
-		} catch {
+		} catch (System.Exception e) {
 			time = File.GetCreationTimeUtc  (path);
 		} 
 
